function [ x,y ] = solveBySOR( A, b, x0, omega, kMax )
%SOLVELCP Solve the linear equation
%   Ax = b
%   By successive over-relaxation wtih parameter omega, kMax steps
%   and initial guess x0

n = length(x0);
assert( length(b)==n );
assert( size(x0,2)==1);
assert( size(b,2)==1);
assert( size(A,1)==n );
assert( size(A,2)==n );

n = length(x0);
y = zeros(n,1);
lastX = x0';
for k=1:kMax
    currentX = zeros(1,n);
    for i=1:n        
        term1 = 0;
        if (i>1) 
            term1 = sum(A(i,1:(i-1)).*currentX(1:(i-1)));
        end
        r=b(i) - term1 - sum(A(i,i:n).*lastX(i:n));
        currentX(i)=lastX(i) + omega*r/A(i,i);
        y(i)=-r+A(i,i)*(currentX(i)-lastX(i));
    end
    lastX = currentX;
end    
x = lastX';

end

