function [ x,y ] = solveLCP( A, b, x0, omega, kMax )
%SOLVELCP Solve the linear complimentarity problem
%   y = Ax + b
%   x >=0, y>=0
%   x.y = 0 
% (This last condition is called complimentarity, one of x or y is zero so
%  they are complimentary)
%
%  These can be solved in many ways, one approach is the method
%  of systematic overrelaxation. This approach was first done in the
%  paper
%  "THE SOLUTION OF A QUADRATIC PROGRAMMING PROBLEM USING SYSTEMATIC OVERRELAXATION"
%  By Colin Cryer
%  http://epubs.siam.org/doi/pdf/10.1137/0309028

n = length(x0);
assert( length(b)==n );
assert( size(x0,2)==1);
assert( size(b,2)==1);
assert( size(A,1)==n );
assert( size(A,2)==n );

n = length(x0);
y = zeros(n,1);
lastX = x0';
for k=1:kMax
    currentX = zeros(1,n);
    for i=1:n        
        term1 = 0;
        if (i>1) 
            term1 = sum(A(i,1:(i-1)).*currentX(1:(i-1)));
        end
        r=-b(i) - term1 - sum(A(i,i:n).*lastX(i:n));
        currentX(i)=max(0,lastX(i) + omega*r/A(i,i));
        y(i)=-r+A(i,i)*(currentX(i)-lastX(i));
    end
    lastX = currentX;
end    
x = lastX';

end

