%SOLVETRIDIAGONAL Solve the tridiagonal equations
%  b1 x1 + c1 x2                             = d1
%  a2 x1 + b2 x2 + c2 x3                     = d2
%          a3 x2 + b3 x3 + c3 x4             = d3
% ...
function [ x ] = solveTridiagonal( a,b,c,d )

if (length(a)==1)
    x = d(1)/(b(1));    
else
    nextB = b(2:end);
    nextB(1) = b(1)*b(2)-c(1)*a(2);
    nextC = c(2:end);
    nextC(1) = b(1)*c(2);
    nextD = d(2:end);
    nextD(1) = b(1)*d(2)-d(1)*a(2);
    
    xRemainder = solveTridiagonal(a(2:end),nextB,nextC,nextD);    
    
    x1 = (d(1)-c(1)*xRemainder(1))/b(1);
    x = [x1 ; xRemainder];
end
end

